pub enum SupportType {
Full,
Center,
Rigid,
}Expand description
Support type for is_face_sturdy checks.
Determines what kind of support a block face provides for other blocks. Used by fences, walls, torches, etc. to decide if they can connect/attach.
Variants
Full
Full face support - the entire face must be solid. Used by most blocks that need a solid surface.
Center
Center support - only the center of the face needs to be solid. Used by things like hanging signs that only need a small attachment point.
Rigid
Rigid support - most of the face must be solid, but allows small gaps. Used by bells and similar blocks.